@@ -148,7 +148,7 @@ gtk_source_language_get_property (GObject    *object,
 			break;
 
 		case PROP_SECTION:
-			g_value_set_string (value, language->priv->name);
+			g_value_set_string (value, language->priv->section);
 			break;
 
 		case PROP_HIDDEN:
@@ -218,7 +218,7 @@ gtk_source_language_class_init (GtkSourceLanguageClass *klass)
 							      G_PARAM_READABLE));
 
 	g_object_class_install_property (object_class,
-					 PROP_ID,
+					 PROP_NAME,
 					 g_param_spec_string ("name",
 						 	      _("Language name"),
 							      _("Language name"),
@@ -226,7 +226,7 @@ gtk_source_language_class_init (GtkSourceLanguageClass *klass)
 							      G_PARAM_READABLE));
 
 	g_object_class_install_property (object_class,
-					 PROP_ID,
+					 PROP_SECTION,
 					 g_param_spec_string ("section",
 						 	      _("Language section"),
 							      _("Language section"),
